@@ -1,7 +1,7 @@
 package Getopt::Long::EvenLess;
 
-our $DATE = '2016-10-29'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2016-12-02'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 # let's be minimalistic
 #use strict 'subs', 'vars';
@@ -103,13 +103,7 @@ sub GetOptionsFromArray {
             if ($spec =~ /=[fios]\@?\z/) {
                 if (defined $val_in_opt) {
                     # argument is taken after =
-                    if (length $val_in_opt) {
-                        $code_set_val->($opt, $val_in_opt);
-                    } else {
-                        warn "Option $used_name requires an argument\n";
-                        $success = 0;
-                        next ELEM;
-                    }
+                    $code_set_val->($opt, $val_in_opt);
                 } else {
                     if ($i+1 >= @$argv) {
                         # we are the last element
@@ -188,7 +182,7 @@ Getopt::Long::EvenLess - Like Getopt::Long::Less, but with even less features
 
 =head1 VERSION
 
-This document describes version 0.05 of Getopt::Long::EvenLess (from Perl distribution Getopt-Long-EvenLess), released on 2016-10-29.
+This document describes version 0.06 of Getopt::Long::EvenLess (from Perl distribution Getopt-Long-EvenLess), released on 2016-12-02.
 
 =head1 DESCRIPTION
 
@@ -209,7 +203,8 @@ Compared to GL and GLL, it:
 
 =item * does not have Configure()
 
-Nothing to configure, no different modes of operation.
+Nothing to configure, no different modes of operation. GLEL is equivalent to GL
+in this mode: bundling, no_ignore_case, no_getopt_compat, gnu_compat, permute.
 
 =item * does not support increment (C<foo+>)
 
@@ -245,23 +240,23 @@ handler, etc.
 
 B<Startup overhead>. Here's a sample startup overhead benchmark:
 
-                            Rate        run_gl       load_gl   run_gl_less  load_gl_less run_gl_evenless load_gl_evenless   perl
- run_gl            78.71+-0.21/s            --         -1.0%        -66.6%        -66.9%          -80.3%           -80.9% -87.3%
- load_gl           79.55+-0.12/s   1.06+-0.31%            --        -66.2%        -66.6%          -80.1%           -80.7% -87.2%
- run_gl_less      235.68+-0.28/s 199.41+-0.86% 196.28+-0.56%            --         -1.0%          -41.1%           -42.7% -62.1%
- load_gl_less         238+-0.4/s 202.36+-0.95%  199.2+-0.67%   0.98+-0.21%            --          -40.6%           -42.2% -61.7%
- run_gl_evenless    400.3+-1.9/s   408.6+-2.8%   403.3+-2.5%  69.87+-0.83%  68.21+-0.85%              --            -2.7% -35.6%
- load_gl_evenless   411.7+-1.7/s     423+-2.5%   417.5+-2.2%  74.67+-0.73%  72.96+-0.76%     2.82+-0.64%               -- -33.8%
- perl               621.4+-1.8/s   689.4+-3.1%   681.2+-2.6% 163.66+-0.84% 161.09+-0.89%    55.21+-0.87%     50.95+-0.75%     --
+                            Rate     load_gl      run_gl load_gl_less run_gl_less run_gl_evenless load_gl_evenless   perl
+ load_gl           67.11+-0.72/s          --       -2.7%       -68.5%      -68.6%          -81.3%           -81.5% -87.9%
+ run_gl            68.97+-0.46/s   2.8+-1.3%          --       -67.6%      -67.7%          -80.8%           -81.0% -87.5%
+ load_gl_less       212.8+-1.7/s 217.2+-4.2% 208.6+-3.2%           --       -0.3%          -40.7%           -41.3% -61.5%
+ run_gl_less      213.49+-0.99/s 218.1+-3.7% 209.5+-2.5%   0.3+-0.92%          --          -40.5%           -41.2% -61.4%
+ run_gl_evenless    358.8+-2.4/s 434.7+-6.7% 420.2+-4.9%   68.6+-1.7%  68.1+-1.4%              --            -1.1% -35.1%
+ load_gl_evenless   362.9+-4.6/s 440.8+-8.9% 426.2+-7.5%   70.5+-2.5%    70+-2.3%       1.1+-1.4%               -- -34.4%
+ perl               553.1+-3.9/s    724+-11% 701.9+-7.8%  159.8+-2.8% 159.1+-2.2%      54.1+-1.5%       52.4+-2.2%     --
  
  Average times:
-   perl            :     1.6093ms
-   load_gl_evenless:     2.4290ms
-   run_gl_evenless :     2.4981ms
-   load_gl_less    :     4.2017ms
-   run_gl_less     :     4.2430ms
-   load_gl         :    12.5707ms
-   run_gl          :    12.7049ms
+   perl            :     1.8080ms
+   load_gl_evenless:     2.7556ms
+   run_gl_evenless :     2.7871ms
+   run_gl_less     :     4.6841ms
+   load_gl_less    :     4.6992ms
+   run_gl          :    14.4991ms
+   load_gl         :    14.9009ms
 
 =for Pod::Coverage .+
 
